@@ -53,7 +53,8 @@ namespace muGrid {
         nb_cols{this->field.get_default_nb_cols(iter_type)} {
     if (field.get_storage_order() != StorageOrder::ColMajor) {
       std::stringstream s;
-      s << "FieldMap requires column-major storage order, but storage order is "
+      s << "FieldMap requires column-major storage order, but storage order of "
+        << "field '" << field.get_name() << "' is "
         << field.get_storage_order();
       throw RuntimeError(s.str());
     }
@@ -76,7 +77,8 @@ namespace muGrid {
         nb_rows{nb_rows_}, nb_cols{this->stride / nb_rows_} {
     if (field.get_storage_order() != StorageOrder::ColMajor) {
       std::stringstream s;
-      s << "FieldMap requires column-major storage order, but storage order is "
+      s << "FieldMap requires column-major storage order, but storage order of "
+        << "field '" << field.get_name() << "' is "
         << field.get_storage_order();
       throw RuntimeError(s.str());
     }
@@ -106,7 +108,8 @@ namespace muGrid {
         data_ptr{other.data_ptr}, is_initialised{other.is_initialised} {
     if (field.get_storage_order() != StorageOrder::ColMajor) {
       std::stringstream s;
-      s << "FieldMap requires column-major storage order, but storage order is "
+      s << "FieldMap requires column-major storage order, but storage order of "
+        << "field '" << field.get_name() << "' is "
         << field.get_storage_order();
       throw RuntimeError(s.str());
     }
@@ -221,6 +224,12 @@ namespace muGrid {
     return mean;
   }
 
+  /* ---------------------------------------------------------------------- */
+  template <typename T, Mapping Mutability>
+  auto FieldMap<T, Mutability>::get_field() const -> const Field_t & {
+    return this->field;
+  }
+
   /* ---------------------------------------------------------------------- */
   template class FieldMap<Real, Mapping::Const>;
   template class FieldMap<Real, Mapping::Mut>;
@@ -230,4 +239,6 @@ namespace muGrid {
   template class FieldMap<Int, Mapping::Mut>;
   template class FieldMap<Uint, Mapping::Const>;
   template class FieldMap<Uint, Mapping::Mut>;
+  template class FieldMap<Index_t, Mapping::Const>;
+  template class FieldMap<Index_t, Mapping::Mut>;
 }  // namespace muGrid
